pub struct EntryPoint { /* private fields */ }Expand description
Builder for application entry configuration and startup.
Implementations
Sourceimpl EntryPoint
impl EntryPoint
Sourcepub fn new(entry: impl Fn() + 'static) -> Self
pub fn new(entry: impl Fn() + 'static) -> Self
Creates a new entry point builder from the root UI function.
Sourcepub fn module(self, module: impl RenderModule + 'static) -> Self
pub fn module(self, module: impl RenderModule + 'static) -> Self
Adds a render module to the entry registry.
Sourcepub fn plugin(self, plugin: impl Plugin) -> Self
pub fn plugin(self, plugin: impl Plugin) -> Self
Registers a plugin instance with the global plugin registry.
Sourcepub fn plugin_boxed<P: Plugin>(self, plugin: Arc<RwLock<P>>) -> Self
pub fn plugin_boxed<P: Plugin>(self, plugin: Arc<RwLock<P>>) -> Self
Registers a boxed plugin instance with the global plugin registry.
Sourcepub fn package(self, package: impl TesseraPackage) -> Self
pub fn package(self, package: impl TesseraPackage) -> Self
Registers a package into the entry registry.
Sourcepub fn config(self, config: TesseraConfig) -> Self
pub fn config(self, config: TesseraConfig) -> Self
Overrides the renderer configuration for this entry.
Sourcepub fn run_desktop(self) -> Result<(), EventLoopError>
pub fn run_desktop(self) -> Result<(), EventLoopError>
Runs the entry point on desktop platforms.